==> identity-apps-1.2.419-source-release.zip: identity-apps-1.2.419/modules/i18n/src/translations/pt-BR/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "Acesso",
    actions: "ações",
    activate: "Ativar",
    active: "Activo",
    add: "AAdicionar",
    addURL: "Adicione URL",
    all: "Tudo",
    applicationName: "Nome da Aplicação",
    applications: "Formulários",
    approvalStatus: "Status de aprovação",
    approve: "Approve",
    assignees: "Cessionárias",
    authentication: "Autenticação",
    authenticator: "Autenticador",
    // eslint-disable-next-line @typescript-eslint/camelcase
    authenticator_plural: "Autenticadores",
    back: "Voltar",
    browser: "Navegador",
    cancel: "Cancelar",
    challengeQuestionNumber: "Questão Desafio {{number}}",
    change: "Mudança",
    chunkLoadErrorMessage: {
        description: "Ocorreu um erro ao servir o aplicativo solicitado. Tente recarregar o aplicativo.",
        heading: "Quelque chose s'est mal passé",
        primaryActionText: "Recarregue o aplicativo"
    },
    claim: "Afirmação",
    clear: "Apagar",
    close: "Fechar",
    comingSoon: "Em breve",
    completed: "Concluído",
    configure: "Configurar",
    confirm: "Confirme",
    contains: "Contém",
    continue: "Continuar",
    copyToClipboard: "Copiar para área de transferência",
    create: "Crio",
    createdOn: "Criado em",
    dangerZone: "Zona de perigo",
    darkMode: "Modo escuro",
    delete: "Excluir",
    description: "Descrição",
    deviceModel: "Modelo do dispositivo",
    disable: "Desabilitar",
    disabled: "Desativado",
    docs: "Documentos",
    documentation: "Documentação",
    done: "Feito",
    download: "Baixar",
    drag: "Arrasto",
    duplicateURLError: "Este URL já foi adicionado",
    edit: "Editar",
    enable: "Habilitar",
    enabled: "Ativado",
    endsWith: "Termina com",
    equals: "É igual a",
    exitFullScreen: "Sair da tela inteira",
    explore: "Explorar",
    export: "Exportação",
    featureAvailable: "Este recurso estará disponível em breve!",
    filter: "Filtro",
    finish: "Terminar",
    generatePassword: "Gerar senha",
    goBackHome: "Volto para casa",
    goFullScreen: "Ir para tela inteira",
    good: "Boa",
    help: "Socorro",
    hide: "ocultar",
    hidePassword: "Esconder a senha",
    identityProviders: "Fornecedor de identidade",
    import: "Importar",
    initiator: "Iniciador",
    ipAddress: "endereço de IP",
    lastAccessed: "Último acesso",
    lastModified: "Última modificação",
    lastSeen: "Visto pela última vez",
    lastUpdatedOn: "Última atualização em",
    lightMode: "Modo claro",
    loading: "Carregando",
    loginTime: "Hora de início de sessão",
    logout: "Sair",
    maximize: "maximizar",
    minimize: "minimizar",
    more: "Mais",
    myAccount: "Minha conta",
    name: "Nome",
    networkErrorMessage: {
        description: "Tente recarregar o aplicativo.",
        heading: "Quelque chose s'est mal passé",
        primaryActionText: "Recarregue o aplicativo"
    },
    next: "Próximo",
    okay: "OK",
    operatingSystem: "Sistema operacional",
    operations: "Operações",
    overview: "visão global",
    personalInfo: "Informação pessoal",
    pin: "Bastão",
    pinned: "Bastão",
    previous: "Anterior",
    priority: "Prioridade",
    privacy: "Privacidade",
    properties: "Propriedades",
    ready: "Pronta",
    regenerate: "Regenerado",
    register: "Registro",
    reject: "Aprovar",
    release: "Liberação",
    remove: "Retirar",
    removeAll: "Remover tudo",
    required: "Isso é obrigatório",
    reserved: "Reservado",
    resetFilters: "Redefinir filtros",
    retry: "Repetir",
    revoke: "Revogar",
    revokeAll: "Revogar tudo",
    samples: "Amostras",
    save: "Salve",
    sdks: "SDKs",
    search: "Procurar",
    security: "Segurança",
    services: "Serviços",
    setup: "Configurar",
    show: "exposição",
    showAll: "Mostre tudo",
    showLess: "Mostre menos",
    showMore: "Mostre mais",
    showPassword: "Mostrar senha",
    skip: "pular",
    startsWith: "Começa com",
    step: "Passo",
    strong: "Forte",
    submit: "Enviar",
    switch: "Interruptor",
    technologies: "Tecnologias",
    terminate: "Terminar",
    terminateAll: "Terminar tudo",
    terminateSession: "Encerrar sessão",
    tooShort: "Curto demais",
    type: "Tipo",
    unpin: "Solto",
    unpinned: "Solto",
    update: "Atualizar",
    user: "Do utilizador",
    verify: "Verificar",
    view: "Visão",
    weak: "Fraco",
    weakPassword: "A força da senha deve ser pelo menos boa."
};

==> identity-apps-1.6.378-source-release.zip: identity-apps-1.6.378/modules/i18n/src/translations/pt-BR/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 LLC. (https://www.wso2.com). All Rights Reserved.
 *
 * WSO2 LLC. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

/**
 * NOTES: No need to care about the max-len for this file since it's easier to
 * translate the strings to other languages easily with editor translation tools.
 */
/* eslint-disable max-len */
export const common: CommonNS = {
    access: "Acesso",
    actions: "ações",
    activate: "Ativar",
    active: "Activo",
    add: "AAdicionar",
    addKey: "Adicionar segredo",
    addURL: "Adicione URL",
    all: "Tudo",
    applicationName: "Nome da Aplicação",
    applications: "Formulários",
    approvalStatus: "Status de aprovação",
    approve: "Approve",
    apps: "Formulários",
    assignee: "Cessionário",
    assignees: "Cessionárias",
    authentication: "Autenticação",
    authenticator: "Autenticador",
    authenticator_plural: "Autenticadores",
    back: "Voltar",
    browser: "Navegador",
    cancel: "Cancelar",
    challengeQuestionNumber: "Questão Desafio {{number}}",
    change: "Mudança",
    chunkLoadErrorMessage: {
        description: "Ocorreu um erro ao servir o aplicativo solicitado. Tente recarregar o aplicativo.",
        heading: "Quelque chose s'est mal passé",
        primaryActionText: "Recarregue o aplicativo"
    },
    claim: "Afirmação",
    clear: "Apagar",
    clientId: "ID do Cliente",
    close: "Fechar",
    comingSoon: "Em breve",
    completed: "Concluído",
    configure: "Configurar",
    confirm: "Confirme",
    contains: "Contém",
    continue: "Continuar",
    copyToClipboard: "Copiar para área de transferência",
    create: "Crio",
    createdOn: "Criado em",
    dangerZone: "Zona de perigo",
    darkMode: "Modo escuro",
    delete: "Excluir",
    description: "Descrição",
    deviceModel: "Modelo do dispositivo",
    disable: "Desabilitar",
    disabled: "Desativado",
    docs: "Documentos",
    documentation: "Documentação",
    done: "Feito",
    download: "Baixar",
    drag: "Arrasto",
    duplicateURLError: "Este URL já foi adicionado",
    edit: "Editar",
    enable: "Habilitar",
    enabled: "Ativado",
    endsWith: "Termina com",
    equals: "É igual a",
    exitFullScreen: "Sair da tela inteira",
    explore: "Explorar",
    export: "Exportação",
    featureAvailable: "Este recurso estará disponível em breve!",
    filter: "Filtro",
    finish: "Terminar",
    generatePassword: "Gerar senha",
    goBackHome: "Volto para casa",
    goFullScreen: "Ir para tela inteira",
    good: "Boa",
    help: "Socorro",
    hide: "ocultar",
    hidePassword: "Esconder a senha",
    identityProviders: "Fornecedor de identidade",
    import: "Importar",
    initiator: "Iniciador",
    ipAddress: "endereço de IP",
    issuer: "emissor",
    lastAccessed: "Último acesso",
    lastModified: "Última modificação",
    lastSeen: "Visto pela última vez",
    lastUpdatedOn: "Última atualização em",
    learnMore: "Saber mais",
    lightMode: "Modo claro",
    loading: "Carregando",
    loginTime: "Hora de início de sessão",
    logout: "Sair",
    maxValidation: "Este valor deve ser menor ou igual a {{max}}.",
    maximize: "maximizar",
    minValidation: "Este valor deve ser maior ou igual a {{min}}.",
    minimize: "minimizar",
    more: "Mais",
    myAccount: "Minha conta",
    name: "Nome",
    networkErrorMessage: {
        description: "Por favor, tente entrar novamente.",
        heading: "Sua sessão expirou",
        primaryActionText: "Entrar"
    },
    new: "novo",
    next: "Próximo",
    okay: "OK",
    operatingSystem: "Sistema operacional",
    operations: "Operações",
    overview: "visão global",
    personalInfo: "Informação pessoal",
    pin: "Bastão",
    pinned: "Bastão",
    preview: "Visualizar",
    previous: "Anterior",
    priority: "Prioridade",
    privacy: "Privacidade",
    properties: "Propriedades",
    ready: "Pronta",
    regenerate: "Regenerado",
    register: "Registro",
    reject: "Aprovar",
    release: "Liberação",
    remove: "Retirar",
    removeAll: "Remover tudo",
    required: "Isso é obrigatório",
    reserved: "Reservado",
    resetFilters: "Redefinir filtros",
    retry: "Repetir",
    revoke: "Revogar",
    revokeAll: "Revogar tudo",
    samples: "Amostras",
    save: "Salve",
    sdks: "SDKs",
    search: "Procurar",
    security: "Segurança",
    services: "Serviços",
    settings: "Configurações",
    setup: "Configurar",
    show: "exposição",
    showAll: "Mostre tudo",
    showLess: "Mostre menos",
    showMore: "Mostre mais",
    showPassword: "Mostrar senha",
    skip: "pular",
    startsWith: "Começa com",
    step: "Passo",
    strong: "Forte",
    submit: "Enviar",
    switch: "Interruptor",
    technologies: "Tecnologias",
    terminate: "Terminar",
    terminateAll: "Terminar tudo",
    terminateSession: "Encerrar sessão",
    tooShort: "Curto demais",
    type: "Tipo",
    unpin: "Solto",
    unpinned: "Solto",
    update: "Atualizar",
    user: "Do utilizador",
    verify: "Verificar",
    view: "Visão",
    weak: "Fraco",
    weakPassword: "A força da senha deve ser pelo menos boa."
};
